@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.7.4.  */
+/* A Bison parser, made by GNU Bison 3.7.6.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -35,8 +35,8 @@
    especially those whose name start with YY_ or yy_.  They are
    private implementation details that can be changed or removed.  */
 
-#ifndef YY_YY__RCFILE_Y_H_INCLUDED
-# define YY_YY__RCFILE_Y_H_INCLUDED
+#ifndef YY_YY_RCFILE_Y_H_INCLUDED
+# define YY_YY_RCFILE_Y_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 1
@@ -261,7 +261,7 @@ union YYSTYPE
   int number;
   char *sval;
 
-#line 265 "../rcfile_y.h"
+#line 265 "rcfile_y.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
@@ -274,4 +274,4 @@ extern YYSTYPE yylval;
 
 int yyparse (void);
 
-#endif /* !YY_YY__RCFILE_Y_H_INCLUDED  */
+#endif /* !YY_YY_RCFILE_Y_H_INCLUDED  */
